##  Setting Up Authentication
On the Credentials tab of the configuration page, enter the user credentials needed to authenticate SAP LeanIX and enable communication with your SAP Signavio instance.
![Setting up Authentication](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27529c967a441014a16896850924e107_LowRes.png)
Setting up Authentication
Find the needed explanations below for each field, along with instructions on how to configure them and the impact these settings have on the overall integration.
